@@ -24,6 +24,7 @@
 #include <sys/time.h>
 #include <string.h>
 #include <stdlib.h>
+#include <locale.h>
 
 #include <glib/gi18n.h>
 #include <glib.h>
@@ -143,6 +144,11 @@ main (int argc, char *argv[])
   gboolean retval;
   GError *error = NULL;
 
+  setlocale (LC_ALL, "");
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
+
   games_scores_startup ();
 
   gettimeofday (&tv, NULL);
